# Generated by roxygen2: do not edit by hand

S3method(as.mcmc,mvnma)
S3method(forest,mvnma)
S3method(hasse,mvrank)
S3method(heatplot,mvrank)
S3method(plot,mvrank)
S3method(print,mvnma)
S3method(print,mvrank)
S3method(print,spiechart)
S3method(print,vikor)
S3method(spiechart,mvrank)
S3method(vikor,matrix)
S3method(vikor,mvrank)
export(as.mcmc)
export(linechart)
export(mvnma)
export(mvrank)
export(spiechart)
export(vikor)
importFrom(R2jags,jags)
importFrom(coda,as.mcmc)
importFrom(coda,as.mcmc.list)
importFrom(dplyr,"%>%")
importFrom(dplyr,all_of)
importFrom(dplyr,any_of)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,desc)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,n_distinct)
importFrom(dplyr,pull)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(forcats,fct_rev)
importFrom(ggplot2,aes)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_tile)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,guide_colourbar)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_fill_gradient)
importFrom(ggplot2,scale_y_discrete)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_minimal)
importFrom(ggplot2,theme_void)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(ggplot2,ylim)
importFrom(graphics,text)
importFrom(magrittr,"%<>%")
importFrom(matrixStats,colSds)
importFrom(meta,forest)
importFrom(meta,gs)
importFrom(meta,metagen)
importFrom(meta,pairwise)
importFrom(netmeta,hasse)
importFrom(netmeta,heatplot)
importFrom(netmeta,netposet)
importFrom(netmeta,rankogram)
importFrom(rlist,list.cbind)
importFrom(rlist,list.rbind)
importFrom(stats,complete.cases)
importFrom(stats,quantile)
importFrom(stats,relevel)
importFrom(utils,combn)
importFrom(utils,packageVersion)
